summaryrefslogtreecommitdiffstats
path: root/kopete/protocols/oscar/liboscar/userdetails.cpp
diff options
context:
space:
mode:
Diffstat (limited to 'kopete/protocols/oscar/liboscar/userdetails.cpp')
-rw-r--r--kopete/protocols/oscar/liboscar/userdetails.cpp6
1 files changed, 3 insertions, 3 deletions
diff --git a/kopete/protocols/oscar/liboscar/userdetails.cpp b/kopete/protocols/oscar/liboscar/userdetails.cpp
index 8a1b6c4e..f8737026 100644
--- a/kopete/protocols/oscar/liboscar/userdetails.cpp
+++ b/kopete/protocols/oscar/liboscar/userdetails.cpp
@@ -363,7 +363,7 @@ void UserDetails::detectClient()
clientMatched=true; // default case will set it to false again if we did not find anything
switch (m_dcLastInfoUpdateTime)
{
- case 0xFFFFFFFFL: //gaim behaves like official AIM so we can't detect them, only look for miranda
+ case 0xFFFFFFFFL: //pidgin behaves like official AIM so we can't detect them, only look for miranda
{
if (m_dcLastExtStatusUpdateTime & 0x80000000)
m_clientName=TQString::fromLatin1("Miranda alpha");
@@ -439,9 +439,9 @@ void UserDetails::detectClient()
m_clientName=TQString::fromLatin1("ICQ2go");
}
}
- else if (hasCap(CAP_BUDDYICON)) // only gaim seems to advertize this on ICQ
+ else if (hasCap(CAP_BUDDYICON)) // only pidgin seems to advertize this on ICQ
{
- m_clientName = TQString::fromLatin1("Gaim");
+ m_clientName = TQString::fromLatin1("Pidgin");
}
else if (hasCap(CAP_XTRAZ))
{